@@ -1,41 +1,22 @@
 require 'spec_helper'
 
-describe 'factory method for Flag type', :shared => true do
-  it 'creates a Class' do
-    DataMapper::Types::Flag.new.should be_instance_of(Class)
-  end
-
-  it 'creates unique a Class each call' do
-    DataMapper::Types::Flag.new.should_not == DataMapper::Types::Flag.new
-  end
-
-  it 'builds up flags map from arguments' do
-    DataMapper::Types::Flag.new(:first, :second, :third).flag_map.values.should == [ :first, :second, :third ]
-  end
-
-  it 'should create keys that is +1 for every increment for the @flag_map hash, staring at 0' do
-    DataMapper::Types::Flag.new(:one, :two, :three, :four, :five).flag_map.keys.should include(0, 1, 2, 3, 4)
-  end
-end
+require './spec/fixtures/tshirt'
 
 try_spec do
-  describe DataMapper::Types::Flag do
-    describe '.new' do
-      it_should_behave_like 'factory method for Flag type'
-    end
-
-    describe '.[]' do
-      it_should_behave_like 'factory method for Flag type'
-    end
-
+  describe DataMapper::Property::Flag do
     describe '.dump' do
       before :all do
-        @flag = DataMapper::Types::Flag[:first, :second, :third, :fourth, :fifth]
+        @flag = DataMapper::TypesFixtures::TShirt.property(
+          :stuff, DataMapper::Property::Flag[:first, :second, :third, :fourth, :fifth])
+
+        @property_klass = DataMapper::Property::Flag
       end
 
+    it_should_behave_like "A property with flags"
+
       describe 'when argument matches a value in the flag map' do
         before :all do
-          @result = @flag.dump(:first, :property)
+          @result = @flag.dump(:first)
         end
 
         it 'returns flag bit of value' do
@@ -45,7 +26,7 @@ try_spec do
 
       describe 'when argument matches 2nd value in the flag map' do
         before :all do
-          @result = @flag.dump(:second, :property)
+          @result = @flag.dump(:second)
         end
 
         it 'returns flag bit of value' do
@@ -55,7 +36,7 @@ try_spec do
 
       describe 'when argument matches multiple Symbol values in the flag map' do
         before :all do
-          @result = @flag.dump([ :second, :fourth ], :property)
+          @result = @flag.dump([ :second, :fourth ])
         end
 
         it 'builds binary flag from key values of all matches' do
@@ -65,7 +46,7 @@ try_spec do
 
       describe 'when argument matches multiple string values in the flag map' do
         before :all do
-          @result = @flag.dump(['first', 'second', 'third', 'fourth', 'fifth'], :property)
+          @result = @flag.dump(['first', 'second', 'third', 'fourth', 'fifth'])
         end
 
         it 'builds binary flag from key values of all matches' do
@@ -75,7 +56,7 @@ try_spec do
 
       describe 'when argument does not match a single value in the flag map' do
         before :all do
-          @result = @flag.dump(:zero, :property)
+          @result = @flag.dump(:zero)
         end
 
         it 'returns zero' do
@@ -86,12 +67,12 @@ try_spec do
 
     describe '.load' do
       before :all do
-        @flag = DataMapper::Types::Flag[:uno, :dos, :tres, :cuatro, :cinco]
+        @flag = DataMapper::TypesFixtures::TShirt.property(:stuff, DataMapper::Property::Flag, :flags => [:uno, :dos, :tres, :cuatro, :cinco])
       end
 
       describe 'when argument matches a key in the flag map' do
         before :all do
-          @result = @flag.load(4,  :property)
+          @result = @flag.load(4)
         end
 
         it 'returns array with a single matching element' do
@@ -101,7 +82,7 @@ try_spec do
 
       describe 'when argument matches multiple keys in the flag map' do
         before :all do
-          @result = @flag.load(10, :property)
+          @result = @flag.load(10)
         end
 
         it 'returns array of matching values' do
@@ -111,7 +92,7 @@ try_spec do
 
       describe 'when argument does not match a single key in the flag map' do
         before :all do
-          @result = @flag.load(nil, :property)
+          @result = @flag.load(nil)
         end
 
         it 'returns an empty array' do
