@@ -1,16 +1,31 @@
 require 'spec_helper'
 
+require './spec/fixtures/network_node'
+
 try_spec do
-  describe DataMapper::Types::IPAddress do
+  describe DataMapper::Property::IPAddress do
     before :all do
       @stored = '81.20.130.1'
       @input  = IPAddr.new(@stored)
+      @property = DataMapper::TypesFixtures::NetworkNode.properties[:ip_address]
+    end
+
+    describe '#valid?' do
+      describe "with a String" do
+        subject { @property.valid?(@stored) }
+        it { subject.should be(true) }
+      end
+
+      describe "with an IPAddr" do
+        subject { @property.valid?(@input) }
+        it { subject.should be(true) }
+      end
     end
 
     describe '.dump' do
       describe 'when argument is an IP address given as Ruby object' do
         before :all do
-          @result = DataMapper::Types::IPAddress.dump(@input, :property)
+          @result = @property.dump(@input)
         end
 
         it 'dumps input into a string' do
@@ -20,7 +35,7 @@ try_spec do
 
       describe 'when argument is nil' do
         before :all do
-          @result = DataMapper::Types::IPAddress.dump(nil, :property)
+          @result = @property.dump(nil)
         end
 
         it 'returns nil' do
@@ -30,7 +45,7 @@ try_spec do
 
       describe 'when input is a blank string' do
         before :all do
-          @result = DataMapper::Types::IPAddress.dump('', :property)
+          @result = @property.dump('')
         end
 
         it 'retuns a blank string' do
@@ -42,7 +57,7 @@ try_spec do
     describe '.load' do
       describe 'when argument is a valid IP address as a string' do
         before :all do
-          @result = DataMapper::Types::IPAddress.load(@stored, :property)
+          @result = @property.load(@stored)
         end
 
         it 'returns IPAddr instance from stored value' do
@@ -52,7 +67,7 @@ try_spec do
 
       describe 'when argument is nil' do
         before :all do
-          @result = DataMapper::Types::IPAddress.load(nil, :property)
+          @result = @property.load(nil)
         end
 
         it 'returns nil' do
@@ -62,7 +77,7 @@ try_spec do
 
       describe 'when argument is a blank string' do
         before :all do
-          @result = DataMapper::Types::IPAddress.load('', :property)
+          @result = @property.load('')
         end
 
         it 'returns IPAddr instance from stored value' do
@@ -72,7 +87,7 @@ try_spec do
 
       describe 'when argument is an Array instance' do
         before :all do
-          @operation = lambda { DataMapper::Types::IPAddress.load([], :property) }
+          @operation = lambda { @property.load([]) }
         end
 
         it 'raises ArgumentError with a meaningful message' do
@@ -84,7 +99,7 @@ try_spec do
     describe '.typecast' do
       describe 'when argument is an IpAddr object' do
         before :all do
-          @result = DataMapper::Types::IPAddress.typecast(@input, :property)
+          @result = @property.typecast(@input)
         end
 
         it 'does not change the value' do
@@ -94,7 +109,7 @@ try_spec do
 
       describe 'when argument is a valid IP address as a string' do
         before :all do
-          @result = DataMapper::Types::IPAddress.typecast(@stored, :property)
+          @result = @property.typecast(@stored)
         end
 
         it 'instantiates IPAddr instance' do
